@@ -63,10 +63,10 @@ define ([
             'preamble': null,
             'aclProfile': 'admin',
             'entries': [entries.ePnick, entries.ePsec_id, entries.ePfullname,
-                        entries.ePemail, entries.ePremark, entries.LDAPdochazka],
+                        entries.ePemail, entries.ePremark],
             'hook': lib.holdObject,
             'miniMenu': {
-                entries: ['masqEmployee'],
+                entries: ['ldapSync', 'masqEmployee'],
                 back: ['Back', 'mainEmpl']
             }
         });
